<?php
/*
Plugin Name: Add New Default Avatar
Plugin URI: http://trepmal.com/plugins/add-new-default-avatar
Description: Add new option to the Default Avatar list. 
Author: Kailey Lampert
Version: 1.2.1
Author URI: http://kaileylampert.com/
*/
/*
	Copyright (C) 2011  Kailey Lampert

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

new kl_addnewdefaultavatar( );

class kl_addnewdefaultavatar {
	function kl_addnewdefaultavatar( ) {
		add_filter( 'avatar_defaults' , array( &$this , 'addavatar' ) );
		add_filter( 'admin_init' , array( &$this , 'register_fields' ) );
		add_filter( 'get_avatar', array( &$this, 'insert_img_correctly' ), 10, 5 );
	}
	function register_fields() {
		register_setting( 'discussion', 'kl_addnewdefaultavatar', array( &$this, 'validate') );
		add_settings_field('anda_setting', __('Add New Default Avatar' , 'anda' ) , array(&$this, 'anda_fields') , 'discussion', 'avatars', $args = array()); 
	}
	function anda_fields() {
		$value = get_option( 'kl_addnewdefaultavatar', array( 'name' => 'Custom Avatar', 'url' => 'http://colorto.me/png/%size%/row2/purple/yellow/orange/blue/' ) );
		echo '<input type="text" name="kl_addnewdefaultavatar[name]" value="'. $value['name'] .'" size="15" />';
		echo '<input type="text" name="kl_addnewdefaultavatar[url]" value="'. $value['url'] .'" size="35" />';
		echo '<p>' . __( 'Some themes won\'t resize your image to fit, so it\'s best to use an image that\'s already the right size.', 'anda' );
		echo '<br />';
		echo sprintf( __( 'However if your image accepts a size argument, you can use %1$s. Example: %2$s', 'anda' ), '<code>%size%</code>', '<code>http://colorto.me/png/%size%/row2/purple/yellow/orange/blue/</code>' ) . '</p>';
	}
	function validate( $input ) {
		$input['name'] = esc_attr( $input['name'] );
		$input['url'] = esc_url( $input['url'] );			
		return $input;
	}
	function addavatar ( $avatar_defaults ) {
		if ( $opts = get_option( 'kl_addnewdefaultavatar' ) ) {
			$av = html_entity_decode(  $opts['url'] );
			$avatar_defaults[ $av ] = $opts['name'];
		}
		return $avatar_defaults;
	}
	function insert_img_correctly( $avatar, $id_or_email, $size, $default, $alt ) {
		
		//determine email address
		if ( is_numeric( $id_or_email ) ) 
			$email = get_userdata( $id_or_email )->user_email;
		elseif ( is_object( $id_or_email ) ) 
			$email = $id_or_email->comment_author_email;
		else
			$email = $id_or_email;
		
		//get selected option
		$selected = get_option('avatar_default');
		//get custom options (for comparison)
		$extras = apply_filters( 'avatar_defaults', array() );
		
		//for matching, below
		//remove size query added to custom options
		$default_minus_size = str_replace("?s=$size", '', $default );

		//only do this processing if:
		//the 'selected' avatar is one of our cutsom options (most cases. selected is global setting.)
		//or
		//the 'default' avatar is one of our custom options (admin list. default passed to func)
		if ( isset( $extras[ $default_minus_size ] ) || isset( $extras[ $selected ] ) ) {
			$email = empty( $email ) ? 'nobody' : md5( $email );
			
			//in rare cases were there is no email associated with the comment (like Mr WordPress)
			//we have to work around a bit to insert the custom avatar
			// 'www' version for WP2.9 and older
			if ( strpos( $default, 'http://0.gravatar.com/avatar/') === 0 || strpos( $default, 'http://www.gravatar.com/avatar/') === 0 )
				$avatar = str_replace( $default, $selected, $avatar );
			
			//hack the correct size parameter back in, if necessary
			$avatar = str_replace( '%size%', $size, $avatar );
			$avatar = str_replace( urlencode('%size%'), $size, $avatar );
		}
		return $avatar;
	}	
}